<!-- Basic Meta Tags -->
<title>[Page Title - 50-60 characters] | [Site Name]</title>
<meta name="description" content="[Meta description - 150-160 characters with CTA]">
<meta name="keywords" content="[keyword1], [keyword2], [keyword3]">
<meta name="author" content="[Author Name]">
<link rel="canonical" href="[https://example.com/page-url]">

<!-- Open Graph (Facebook, LinkedIn) -->
<meta property="og:title" content="[Page Title]">
<meta property="og:description" content="[Description for social sharing]">
<meta property="og:type" content="article">
<meta property="og:url" content="[https://example.com/page-url]">
<meta property="og:image" content="[https://example.com/og-image.jpg]">
<meta property="og:site_name" content="[Site Name]">

<!-- Twitter Card -->
<meta name="twitter:card" content="summary_large_image">
<meta name="twitter:title" content="[Page Title]">
<meta name="twitter:description" content="[Description for Twitter]">
<meta name="twitter:image" content="[https://example.com/twitter-image.jpg]">
<meta name="twitter:site" content="[@handle]">
<meta name="twitter:creator" content="[@author_handle]">

<!-- Additional SEO Tags -->
<meta name="robots" content="index, follow">
<meta name="googlebot" content="index, follow">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<meta charset="UTF-8">
